# -*- coding: utf-8 -*-
# project-system (c) Ian Dennis Miller

__project__ = 'project-system'
__version__ = '0.2.4'
__author__ = 'Ian Dennis Miller'
__email__ = 'iandennismiller@gmail.com'
__url__ = 'http://project-system.readthedocs.io'
__copyright__ = '2016-2019 Ian Dennis Miller'
